@@ -27,7 +27,12 @@ public Q_SLOTS:
     void addTitle(const QString &message);
 
 private:
-    enum LogType { AddEndLine = 0, AddInfo, AddError, AddTitle };
+    enum LogType {
+        AddEndLine = 0,
+        AddInfo,
+        AddError,
+        AddTitle
+    };
     void addLogLine(const QString &message, LogType type);
     QString mFileName;
     QTextStream mTextStream;
