@@ -52,7 +52,7 @@ void ExportCalendarsJobInterfaceTest::exportCalendar()
 
     auto exportNote = new ExportCalendarsJobInterfaceTestImpl(this, options, file->archiveStorage(), 1);
     exportNote->setListOfResource(lstInfo);
-    exportNote->setPathConfig(QLatin1String(configpath));
+    exportNote->setPathConfig(QLatin1StringView(configpath));
     file->setAbstractImportExportJob(exportNote);
     file->start();
     delete exportNote;
