@@ -72,8 +72,6 @@ QMap<Utils::AppsType, Utils::importExportParameters> TemplateSelection::loadTemp
                     type = Utils::KAlarm;
                 } else if (mStreamReader->name() == QLatin1StringView("korganizer")) {
                     type = Utils::KOrganizer;
-                } else if (mStreamReader->name() == QLatin1StringView("knotes")) {
-                    type = Utils::KNotes;
                 } else if (mStreamReader->name() == QLatin1StringView("akregator")) {
                     type = Utils::Akregator;
                 }
@@ -161,11 +159,6 @@ void TemplateSelection::createTemplate(const QMap<Utils::AppsType, Utils::import
             saveParameters(i.value().types);
             mStreamWriter->writeEndElement();
             break;
-        case Utils::KNotes:
-            mStreamWriter->writeStartElement(QStringLiteral("knotes"));
-            saveParameters(i.value().types);
-            mStreamWriter->writeEndElement();
-            break;
         case Utils::Akregator:
             mStreamWriter->writeStartElement(QStringLiteral("akregator"));
             saveParameters(i.value().types);
