@@ -23,7 +23,9 @@ private:
     void slotSelectAll();
     void slotUnselectAll();
 
-    enum DataType { ResourceIdentifier = Qt::UserRole + 1 };
+    enum DataType {
+        ResourceIdentifier = Qt::UserRole + 1
+    };
 
     void readConfig();
     void writeConfig();
